@@ -18,7 +18,6 @@ from data.models.models import Hardware, DHT22, MCP3008, ModProbe, PiPico, VEML7
 from data.serializers.serializers import HardwareSerializer, ChannelSerializer, AccessorySerializer, \
     CalibrationSerializer, HubSerializer, HardwareIOSerializer
 
-
 SPI = 'SPI'
 Serial = 'Serial'
 PWM = 'PWM'
@@ -611,8 +610,14 @@ class HubViewSet(viewsets.ModelViewSet):
     def get_queryset(self):
         return Hub.objects.all()
 
-    def listHubHardware(self, hub_id):
+    def listHubHardware(self, request, hub_id):
+        form_type = HardwareTypeForm(initial={'type': 'PiPico'})
+        hardware_form = HardwarePiPicoForm(initial={'type': 'PiPico'})
         hardware = Hub.objects.get(pk=hub_id).hardware_set.all()
+        if request.accepted_renderer.format == 'html':
+            return Response({"form": hardware_form, "type_form": form_type, "hardwares": hardware},
+                            template_name='hardwares.html')
+
         serialized_hardware = HardwareSerializer().to_json_array(hardware)
         return JsonResponse(serialized_hardware, status=200, safe=False)
 
@@ -621,9 +626,14 @@ class HubViewSet(viewsets.ModelViewSet):
         serialized_channels = ChannelSerializer(many=True).to_representation(channels)
         return JsonResponse(serialized_channels, status=200, safe=False)
 
-    def listHubAccessories(self, hub_id):
+    def listHubAccessories(self, request, hub_id):
         accessories = Hub.objects.get(pk=hub_id).accessory_set.all()
+
+        if request.accepted_renderer.format == 'html':
+            form = AccessoryForm()
+            return Response({"form": form, "accessories": accessories}, template_name='accessories.html')
         serialized_accessories = AccessorySerializer(many=True).to_representation(accessories)
+
         return JsonResponse(serialized_accessories, status=200, safe=False)
 
     def about(self, *args, **kwargs):
@@ -659,8 +669,7 @@ class HubViewSet(viewsets.ModelViewSet):
             hub_data = HubSerializer(instance=hub).to_representation(hub)
             return JsonResponse(hub_data, status=200)
 
-
-    def postHub( request):
+    def postHub(request):
         # request should be ajax and method should be POST.
         if request.is_ajax() and request.method == "POST":
             # get the form data
@@ -775,10 +784,12 @@ class IOViewSet(viewsets.ModelViewSet):
 def video_streams(request):
     return render(request, "streams.html", None)
 
+
 from django.contrib.auth import login, authenticate
 from django.contrib.auth.forms import UserCreationForm
 from django.shortcuts import render, redirect
 
+
 def signup(request):
     if request.method == 'POST':
         form = UserCreationForm(request.POST)
@@ -791,4 +802,4 @@ def signup(request):
             return redirect('hubs')
     else:
         form = UserCreationForm()
-    return render(request, 'registration/signup.html', {'form': form})
\ No newline at end of file
+    return render(request, 'registration/signup.html', {'form': form})
